@@ -19,13 +19,13 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <krandom.h>
-#include <k3urldrag.h>
+#include <kglobalsettings.h>
 #include <kio/netaccess.h>
 
 #include <QImage>
 #include <QLayout>
 #include <QEvent>
-#include <Q3DragObject>
+#include <QDrag>
 #include <QTimer>
 #include <QPoint>
 #include <QFrame>
@@ -34,6 +34,8 @@
 #include <QVBoxLayout>
 #include <QDragEnterEvent>
 #include <QMouseEvent>
+#include <QUrl>
+#include <QList>
 #include <QTextDocument>
 
 #include "playlistcollection.h"
@@ -57,24 +59,26 @@ struct Line : public QFrame
 // NowPlaying
 ////////////////////////////////////////////////////////////////////////////////
 
-NowPlaying::NowPlaying(QWidget *parent, PlaylistCollection *collection, const char *name) :
-    Q3HBox(parent, name),
+NowPlaying::NowPlaying(QWidget *parent, PlaylistCollection *collection) :
+    QWidget(parent),
     m_observer(this, collection),
+    // Also watch the collection
+    m_collectionListObserver(this, CollectionList::instance()),
     m_collection(collection)
 {
-    // m_observer is set to watch the PlaylistCollection, also watch for
-    // changes that come from CollectionList.
+    setObjectName("NowPlaying");
 
-    CollectionList::instance()->addObserver(&m_observer);
+    QHBoxLayout *layout = new QHBoxLayout(this);
+    setLayout(layout);
 
-    layout()->setMargin(5);
-    layout()->setSpacing(3);
-    setFixedHeight(imageSize + 2 + layout()->margin() * 2);
+    layout->setMargin(0);
+    layout->setSpacing(3);
+    setFixedHeight(imageSize + 2);
 
-    setStretchFactor(new CoverItem(this), 0);
-    setStretchFactor(new TrackItem(this), 2);
-    setStretchFactor(new Line(this), 0);
-    setStretchFactor(new HistoryItem(this), 1);
+    layout->addWidget(new CoverItem(this), 0);
+    layout->addWidget(new TrackItem(this), 2);
+    layout->addWidget(new Line(this), 0);
+    layout->addWidget(new HistoryItem(this), 1);
 
     connect(PlayerManager::instance(), SIGNAL(signalPlay()), this, SLOT(slotUpdate()));
     connect(PlayerManager::instance(), SIGNAL(signalStop()), this, SLOT(slotUpdate()));
@@ -98,6 +102,7 @@ void NowPlaying::slotUpdate()
 
     if(file.isNull()) {
         hide();
+        emit nowPlayingHidden();
         return;
     }
     else
@@ -117,8 +122,6 @@ CoverItem::CoverItem(NowPlaying *parent) :
 {
     setObjectName("CoverItem");
     setFixedHeight(parent->height() - parent->layout()->margin() * 2);
-    setFrameStyle(Box | Plain);
-    setLineWidth(1);
     setMargin(1);
     setAcceptDrops(true);
 }
@@ -167,40 +170,48 @@ void CoverItem::mouseMoveEvent(QMouseEvent *e)
         return;
 
     QPoint diff = m_dragStart - e->globalPos();
-    if(qAbs(diff.x()) > 1 || qAbs(diff.y()) > 1) {
+    if(diff.manhattanLength() > KGlobalSettings::dndEventDelay()) {
 
         // Start a drag.
 
         m_dragging = true;
 
-        CoverDrag *drag = new CoverDrag(m_file.coverInfo()->coverId(), this);
-        drag->drag();
+        QDrag *drag = new QDrag(this);
+        CoverDrag *data = new CoverDrag(m_file.coverInfo()->coverId());
+
+        drag->setMimeData(data);
+        drag->exec(Qt::CopyAction);
     }
 }
 
 void CoverItem::dragEnterEvent(QDragEnterEvent *e)
 {
-    e->setAccepted(Q3ImageDrag::canDecode(e) || K3URLDrag::canDecode(e) || CoverDrag::canDecode(e));
+    e->setAccepted(CoverDrag::isCover(e->mimeData()) || e->mimeData()->hasUrls());
 }
 
 void CoverItem::dropEvent(QDropEvent *e)
 {
     QImage image;
-    KUrl::List urls;
+    QList<QUrl> urls;
     coverKey key;
 
     if(e->source() == this)
         return;
 
-    if(Q3ImageDrag::decode(e, image)) {
-        m_file.coverInfo()->setCover(image);
-        update(m_file);
-    }
-    else if(CoverDrag::decode(e, key)) {
+    key = CoverDrag::idFromData(e->mimeData());
+    if(key != CoverManager::NoMatch) {
         m_file.coverInfo()->setCoverId(key);
         update(m_file);
     }
-    else if(K3URLDrag::decode(e, urls)) {
+    else if(e->mimeData()->hasImage()) {
+        m_file.coverInfo()->setCover(qvariant_cast<QImage>(e->mimeData()->imageData()));
+        update(m_file);
+    }
+    else {
+        urls = e->mimeData()->urls();
+        if(urls.isEmpty())
+            return;
+
         QString fileName;
 
         if(KIO::NetAccess::download(urls.front(), fileName, this)) {
@@ -232,7 +243,8 @@ TrackItem::TrackItem(NowPlaying *parent) :
 
     QVBoxLayout *layout = new QVBoxLayout(this);
 
-    m_label = new LinkLabel(this);
+    m_label = new QLabel(this);
+    m_label->setWordWrap(true);
 
     m_label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::LinksAccessibleByKeyboard);
 
@@ -247,6 +259,11 @@ TrackItem::TrackItem(NowPlaying *parent) :
 
     connect(m_label, SIGNAL(linkActivated(const QString &)), this,
             SLOT(slotOpenLink(const QString &)));
+
+    // Ensure that if we're filtering results, that the filtering is cleared if we
+    // hide the now playing bar so that the user can select tracks normally.
+
+    connect(parent, SIGNAL(nowPlayingHidden()), SLOT(slotClearShowMore()));
 }
 
 void TrackItem::update(const FileHandle &file)
@@ -298,12 +315,19 @@ void TrackItem::slotUpdate()
     m_label->setFixedHeight(qMin(imageSize, m_label->heightForWidth(m_label->width())));
 }
 
+void TrackItem::slotClearShowMore()
+{
+    PlaylistCollection *collection = NowPlayingItem::parent()->collection();
+    Q_ASSERT(collection);
+    collection->clearShowMore();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // HistoryItem
 ////////////////////////////////////////////////////////////////////////////////
 
 HistoryItem::HistoryItem(NowPlaying *parent) :
-    LinkLabel(parent),
+    QLabel(parent),
     NowPlayingItem(parent)
 {
     setFixedHeight(parent->height() - parent->layout()->margin() * 2);
