@@ -76,39 +76,44 @@ Mixer_ALSA::~Mixer_ALSA()
 int Mixer_ALSA::identify( snd_mixer_selem_id_t *sid )
 {
    QString name = snd_mixer_selem_id_get_name( sid );
-
-   if ( name.indexOf( "master"     , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::VOLUME;
-   if ( name.indexOf( "master mono", 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::VOLUME;
-   if ( name.indexOf( "front"     , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::VOLUME;
-   if ( name.indexOf( "pc speaker" , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::VOLUME;
-   if ( name.indexOf( "capture"    , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::RECMONITOR;
-   if ( name.indexOf( "music"      , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::MIDI;
-   if ( name.indexOf( "Synth"      , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::MIDI;
-   if ( name.indexOf( "FM"         , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::MIDI;
-   if ( name.indexOf( "headphone"  , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::HEADPHONE;
-   if ( name.indexOf( "bass"       , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::BASS;
-   if ( name.indexOf( "treble"     , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::TREBLE;
-   if ( name.indexOf( "cd"         , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::CD;
-   if ( name.indexOf( "video"      , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::VIDEO;
-   if ( name.indexOf( "pcm"        , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::AUDIO;
-   if ( name.indexOf( "Wave"       , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::AUDIO;
-   if ( name.indexOf( "surround"   , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::SURROUND_BACK;
-   if ( name.indexOf( "center"     , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::SURROUND_CENTERFRONT;
-   if ( name.indexOf( "ac97"       , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::AC97;
-   if ( name.indexOf( "coaxial "   , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::DIGITAL;
-   if ( name.indexOf( "optical"    , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::DIGITAL;
-   if ( name.indexOf( "iec958"     , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::DIGITAL;
-   if ( name.indexOf( "mic"        , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::MICROPHONE;
-   if ( name.indexOf( "lfe"        , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::SURROUND_LFE;
-   if ( name.indexOf( "monitor"    , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::RECMONITOR;
-   if ( name.indexOf( "3d"         , 0, Qt::CaseInsensitive ) != -1 ) return MixDevice::SURROUND;  // Should be probably some own icon
+ kDebug() << name;
+   if (name.contains("master"     , Qt::CaseInsensitive)) return MixDevice::VOLUME;
+   if (name.contains("master mono", Qt::CaseInsensitive)) return MixDevice::VOLUME;
+   if (name.contains("front"      , Qt::CaseInsensitive) &&
+      !name.contains("mic"        , Qt::CaseInsensitive)) return MixDevice::VOLUME;
+   if (name.contains("pc speaker" , Qt::CaseInsensitive)) return MixDevice::SPEAKER;
+   if (name.contains("capture"    , Qt::CaseInsensitive)) return MixDevice::RECMONITOR;
+   if (name.contains("music"      , Qt::CaseInsensitive)) return MixDevice::MIDI;
+   if (name.contains("Synth"      , Qt::CaseInsensitive)) return MixDevice::MIDI;
+   if (name.contains("FM"         , Qt::CaseInsensitive)) return MixDevice::MIDI;
+   if (name.contains("headphone"  , Qt::CaseInsensitive)) return MixDevice::HEADPHONE;
+   if (name.contains("bass"       , Qt::CaseInsensitive)) return MixDevice::BASS;
+   if (name.contains("treble"     , Qt::CaseInsensitive)) return MixDevice::TREBLE;
+   if (name.contains("cd"         , Qt::CaseInsensitive)) return MixDevice::CD;
+   if (name.contains("video"      , Qt::CaseInsensitive)) return MixDevice::VIDEO;
+   if (name.contains("pcm"        , Qt::CaseInsensitive)) return MixDevice::AUDIO;
+   if (name.contains("Wave"       , Qt::CaseInsensitive)) return MixDevice::AUDIO;
+   if (name.contains("surround"   , Qt::CaseInsensitive)) return MixDevice::SURROUND_BACK;
+   if (name.contains("center"     , Qt::CaseInsensitive)) return MixDevice::SURROUND_CENTERFRONT;
+   if (name.contains("ac97"       , Qt::CaseInsensitive)) return MixDevice::AC97;
+   if (name.contains("coaxial"    , Qt::CaseInsensitive)) return MixDevice::DIGITAL;
+   if (name.contains("optical"    , Qt::CaseInsensitive)) return MixDevice::DIGITAL;
+   if (name.contains("iec958"     , Qt::CaseInsensitive)) return MixDevice::DIGITAL;
+   if (name.contains("digital"    , Qt::CaseInsensitive)) return MixDevice::DIGITAL;
+   if (name.contains("mic boost"  , Qt::CaseInsensitive)) return MixDevice::MICROPHONE_BOOST;
+   if (name.contains("Mic Front"  , Qt::CaseInsensitive)) return MixDevice::MICROPHONE_FRONT;
+   if (name.contains("Front Mic"  , Qt::CaseInsensitive)) return MixDevice::MICROPHONE_FRONT;
+   if (name.contains("mic"        , Qt::CaseInsensitive)) return MixDevice::MICROPHONE;
+   if (name.contains("lfe"        , Qt::CaseInsensitive)) return MixDevice::SURROUND_LFE;
+   if (name.contains("monitor"    , Qt::CaseInsensitive)) return MixDevice::RECMONITOR;
+   if (name.contains("3d"         , Qt::CaseInsensitive)) return MixDevice::SURROUND;  // Should be probably some own icon
 
    return MixDevice::EXTERNAL;
 }
 
 int Mixer_ALSA::open()
 {
-    bool masterChosen = false;
+    int masterChosenQuality = 0;
     int err;
 
     snd_mixer_elem_t *elem;
@@ -201,21 +206,43 @@ int Mixer_ALSA::open()
          qDeleteAll(enumList); // clear temporary list
 
         // --- Recommended master ----------------------------------------
-        if ( mdID == "PCM:0" ) {
-            kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
-            m_recommendedMaster = md;
-            masterChosen = true;
-        }
-        else if (!masterChosen && ct==MixDevice::VOLUME) {
-            // Determine a nicer MasterVolume
-            kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
-            m_recommendedMaster = md;
-            masterChosen = true;
-        }
+        if ( md->playbackVolume().hasVolume() )
+        {
+          if ( mdID == "Master:0" && masterChosenQuality < 100 ) {
+              kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
+              m_recommendedMaster = md;
+              masterChosenQuality = 100;
+          }
+          else if ( mdID == "PCM:0" && masterChosenQuality < 80) {
+              kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
+              m_recommendedMaster = md;
+              masterChosenQuality = 80;
+          }
+          else if ( mdID == "Front:0" && masterChosenQuality < 60) {
+              kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
+              m_recommendedMaster = md;
+              masterChosenQuality = 60;
+          }
+          else if ( mdID == "DAC:0" && masterChosenQuality < 50) {
+              kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
+              m_recommendedMaster = md;
+              masterChosenQuality = 50;
+          }
+          else if ( mdID == "Headphone:0" && masterChosenQuality < 40) {
+              kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
+              m_recommendedMaster = md;
+              masterChosenQuality = 40;
+          }
+          else if ( mdID == "Master Mono:0" && masterChosenQuality < 30) {
+              kDebug(67100) << "Setting m_recommendedMaster to " << mdID;
+              m_recommendedMaster = md;
+              masterChosenQuality = 30;
+          }
 
-        //kDebug(67100) << "ALSA create MDW, vol= " << *vol;
-        delete volPlay;
-        delete volCapture;
+          //kDebug(67100) << "ALSA create MDW, vol= " << *vol;
+          delete volPlay;
+          delete volCapture;
+        }
     } // for all elems
 
 
@@ -364,29 +391,39 @@ Volume* Mixer_ALSA::addVolume(snd_mixer_elem_t *elem, bool capture)
 
     // --- Regular control (not enumerated) ---
     Volume::ChannelMask chn = Volume::MNONE;
-    Volume::ChannelMask chnTmp;
 
-    bool hasVolume = capture
-        ? snd_mixer_selem_has_capture_volume(elem)
-        : snd_mixer_selem_has_playback_volume(elem);
-    if ( hasVolume ) {
-        //kDebug(67100) << "has_xyz_volume()";
-        // @todo looks like this supports only 2 channels here
-        bool mono = capture
-            ? snd_mixer_selem_is_capture_mono(elem)
-            : snd_mixer_selem_is_playback_mono(elem);
-        chnTmp = mono
-            ? Volume::MLEFT
-            : (Volume::ChannelMask)(Volume::MLEFT | Volume::MRIGHT);
-        chn = (Volume::ChannelMask) (chn | chnTmp);
-        if ( capture) {
-            snd_mixer_selem_get_capture_volume_range( elem, &minVolume, &maxVolume );
-        }
-        else  {
-            snd_mixer_selem_get_playback_volume_range( elem, &minVolume, &maxVolume );
-        }
+
+    // Add volumes
+    if ( !capture && snd_mixer_selem_has_playback_volume(elem) ) {
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_FRONT_LEFT  )) chn = (Volume::ChannelMask)( chn | Volume::MLEFT);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_FRONT_RIGHT )) chn = (Volume::ChannelMask)( chn | Volume::MRIGHT);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_FRONT_CENTER)) chn = (Volume::ChannelMask)( chn | Volume::MCENTER);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_REAR_LEFT   )) chn = (Volume::ChannelMask)( chn | Volume::MSURROUNDLEFT);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_REAR_RIGHT  )) chn = (Volume::ChannelMask)( chn | Volume::MSURROUNDRIGHT);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_REAR_CENTER )) chn = (Volume::ChannelMask)( chn | Volume::MREARCENTER);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_WOOFER      )) chn = (Volume::ChannelMask)( chn | Volume::MWOOFER);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_SIDE_LEFT   )) chn = (Volume::ChannelMask)( chn | Volume::MREARSIDELEFT);
+        if ( snd_mixer_selem_has_playback_channel(elem,SND_MIXER_SCHN_SIDE_RIGHT  )) chn = (Volume::ChannelMask)( chn | Volume::MREARSIDERIGHT);
+        snd_mixer_selem_get_playback_volume_range( elem, &minVolume, &maxVolume );
+    }
+    else if ( capture && snd_mixer_selem_has_capture_volume(elem) ) {
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_FRONT_LEFT  )) chn = (Volume::ChannelMask)( chn | Volume::MLEFT);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_FRONT_RIGHT )) chn = (Volume::ChannelMask)( chn | Volume::MRIGHT);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_FRONT_CENTER)) chn = (Volume::ChannelMask)( chn | Volume::MCENTER);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_REAR_LEFT   )) chn = (Volume::ChannelMask)( chn | Volume::MSURROUNDLEFT);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_REAR_RIGHT  )) chn = (Volume::ChannelMask)( chn | Volume::MSURROUNDRIGHT);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_REAR_CENTER )) chn = (Volume::ChannelMask)( chn | Volume::MREARCENTER);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_WOOFER      )) chn = (Volume::ChannelMask)( chn | Volume::MWOOFER);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_SIDE_LEFT   )) chn = (Volume::ChannelMask)( chn | Volume::MREARSIDELEFT);
+        if ( snd_mixer_selem_has_capture_channel(elem,SND_MIXER_SCHN_SIDE_RIGHT  )) chn = (Volume::ChannelMask)( chn | Volume::MREARSIDERIGHT);
+        snd_mixer_selem_get_capture_volume_range( elem, &minVolume, &maxVolume );
     }
 
+
+    // Chek if this control has at least one volume control
+    bool hasVolume = (chn != Volume::MNONE);
+
+    // Chek if a appropriate switch is present (appropriate means, based o nthe "capture" parameer)
     bool hasCommonSwitch = snd_mixer_selem_has_common_switch ( elem );
 
     bool hasSwitch = hasCommonSwitch |
@@ -395,6 +432,7 @@ Volume* Mixer_ALSA::addVolume(snd_mixer_elem_t *elem, bool capture)
         : snd_mixer_selem_has_playback_switch ( elem );
 
     if ( hasVolume || hasSwitch ) {
+        //kDebug() << "Add somthing with chn=" << chn << ", capture=" << capture;
         vol = new Volume( chn, maxVolume, minVolume, hasSwitch, capture);
     }
 
@@ -659,7 +697,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, MixDevice *md )
     Volume& volumeCapture  = md->captureVolume();
     int devnum = id2num(id);
     int elem_sw;
-    long left, right;
+    long vol;
 
     snd_mixer_elem_t *elem = getMixerElem( devnum );
     if ( !elem )
@@ -667,23 +705,31 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, MixDevice *md )
         return 0;
     }
 
-
+    vol = Volume::MNONE;
     // --- playback volume
-    if ( snd_mixer_selem_has_playback_volume( elem ) )
-    {
-        int ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_FRONT_LEFT, &left );
-        if ( ret != 0 ) kDebug(67100) << "readVolumeFromHW(" << devnum << ") [has_playback_volume,R] failed, errno=" << ret;
-        if ( snd_mixer_selem_is_playback_mono ( elem )) {
-            volumePlayback.setVolume( Volume::LEFT , left );
-            volumePlayback.setVolume( Volume::RIGHT, left );
-        }
-        else {
-            int ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_FRONT_RIGHT, &right );
-        if ( ret != 0 ) kDebug(67100) << "readVolumeFromHW(" << devnum << ") [has_playback_volume,R] failed, errno=" << ret;
-            volumePlayback.setVolume( Volume::LEFT , left );
-            volumePlayback.setVolume( Volume::RIGHT, right );
-        }
-    }
+    if ( snd_mixer_selem_has_playback_volume( elem ) ) {
+        for ( int i=0; i<= Volume::CHIDMAX; i++ ) {
+           if ( volumePlayback._chmask & Volume::_channelMaskEnum[i] ) {
+
+               int ret;
+               switch(i) {
+                   case Volume::LEFT         : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_FRONT_LEFT  , &vol); break;
+                   case Volume::RIGHT        : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_FRONT_RIGHT , &vol); break;
+                   case Volume::CENTER       : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_FRONT_CENTER, &vol); break;
+                   case Volume::SURROUNDLEFT : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_REAR_LEFT   , &vol); break;
+                   case Volume::SURROUNDRIGHT: ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_REAR_RIGHT  , &vol); break;
+                   case Volume::REARCENTER   : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_REAR_CENTER , &vol); break;
+                   case Volume::WOOFER       : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_WOOFER      , &vol); break;
+                   case Volume::REARSIDELEFT : ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_SIDE_LEFT   , &vol); break;
+                   case Volume::REARSIDERIGHT: ret = snd_mixer_selem_get_playback_volume( elem, SND_MIXER_SCHN_SIDE_RIGHT  , &vol); break;
+                   default: kDebug() << "FATAL: Unknown channel type for playback << " << i << " ... please report this";  break;
+              }
+              if ( ret != 0 ) kDebug(67100) << "readVolumeFromHW(" << devnum << ") [get_playback_volume] failed, errno=" << ret;
+              else volumePlayback.setVolume( (Volume::ChannelID)i, vol);
+              if (id== "Master:0" || id== "PCM:0" ) { kDebug() << "volumePlayback control=" << id << ", chid=" << i << ", vol=" << vol; }
+          }
+       }
+    } // has playback volume
 
     // --- playback switch
     if ( snd_mixer_selem_has_playback_switch( elem ) )
@@ -692,23 +738,31 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, MixDevice *md )
         md->setMuted( elem_sw == 0 );
     }
 
+    vol = Volume::MNONE;
     // --- capture volume
     if ( snd_mixer_selem_has_capture_volume ( elem ) )
     {
-        int ret = snd_mixer_selem_get_capture_volume ( elem, SND_MIXER_SCHN_FRONT_LEFT, &left );
-        if ( ret != 0 ) kDebug(67100) << "readVolumeFromHW(" << devnum << ") [get_capture_volume,L] failed, errno=" << ret;
-        if ( snd_mixer_selem_is_capture_mono  ( elem )) {
-            volumeCapture.setVolume( Volume::LEFT , left );
-            volumeCapture.setVolume( Volume::RIGHT, left );
-        }
-        else
-        {
-            int ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_FRONT_RIGHT, &right );
-            if ( ret != 0 ) kDebug(67100) << "readVolumeFromHW(" << devnum << ") [has_capture_volume,R] failed, errno=" << ret;
-            volumeCapture.setVolume( Volume::LEFT , left );
-            volumeCapture.setVolume( Volume::RIGHT, right );
-        }
-    }
+        for ( int i=0; i<= Volume::CHIDMAX; i++ ) {
+           if ( volumeCapture._chmask & Volume::_channelMaskEnum[i] ) {
+
+               int ret;
+               switch(i) {
+                   case Volume::LEFT         : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_FRONT_LEFT  , &vol); break;
+                   case Volume::RIGHT        : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_FRONT_RIGHT , &vol); break;
+                   case Volume::CENTER       : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_FRONT_CENTER, &vol); break;
+                   case Volume::SURROUNDLEFT : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_REAR_LEFT   , &vol); break;
+                   case Volume::SURROUNDRIGHT: ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_REAR_RIGHT  , &vol); break;
+                   case Volume::REARCENTER   : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_REAR_CENTER , &vol); break;
+                   case Volume::WOOFER       : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_WOOFER      , &vol); break;
+                   case Volume::REARSIDELEFT : ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_SIDE_LEFT   , &vol); break;
+                   case Volume::REARSIDERIGHT: ret = snd_mixer_selem_get_capture_volume( elem, SND_MIXER_SCHN_SIDE_RIGHT  , &vol);     break;
+                   default: kDebug() << "FATAL: Unknown channel type for capture << " << i << " ... please report this";  break;
+              }
+              if ( ret != 0 ) kDebug(67100) << "readVolumeFromHW(" << devnum << ") [get_capture_volume] failed, errno=" << ret;
+              volumeCapture.setVolume( (Volume::ChannelID)i, vol);
+          }
+       }
+    } // has capture volume
 
     // --- capture switch
     if ( snd_mixer_selem_has_capture_switch( elem ) )
@@ -727,7 +781,6 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, MixDevice *md )
     Volume& volumeCapture  = md->captureVolume();
 
     int devnum = id2num(id);
-    int left, right;
 
     snd_mixer_elem_t *elem = getMixerElem( devnum );
     if ( !elem )
@@ -736,13 +789,28 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, MixDevice *md )
     }
 
     // --- playback volume
-    left  = volumePlayback[ Volume::LEFT ];
-    right = volumePlayback[ Volume::RIGHT ];
-    if (snd_mixer_selem_has_playback_volume( elem ) ) {
-        snd_mixer_selem_set_playback_volume ( elem, SND_MIXER_SCHN_FRONT_LEFT, left );
-        if ( ! snd_mixer_selem_is_playback_mono ( elem ) )
-            snd_mixer_selem_set_playback_volume ( elem, SND_MIXER_SCHN_FRONT_RIGHT, right );
-    }
+    if ( snd_mixer_selem_has_playback_volume( elem ) ) {
+        for ( int i=0; i<= Volume::CHIDMAX; i++ ) {
+           if ( volumePlayback._chmask & Volume::_channelMaskEnum[i] ) {
+
+               int ret;
+               switch(i) {
+                   case Volume::LEFT         : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_FRONT_LEFT  , volumePlayback[i]); break;
+                   case Volume::RIGHT        : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_FRONT_RIGHT , volumePlayback[i]); break;
+                   case Volume::CENTER       : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_FRONT_CENTER, volumePlayback[i]); break;
+                   case Volume::SURROUNDLEFT : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_REAR_LEFT   , volumePlayback[i]); break;
+                   case Volume::SURROUNDRIGHT: ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_REAR_RIGHT  , volumePlayback[i]); break;
+                   case Volume::REARCENTER   : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_REAR_CENTER , volumePlayback[i]); break;
+                   case Volume::WOOFER       : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_WOOFER      , volumePlayback[i]); break;
+                   case Volume::REARSIDELEFT : ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_SIDE_LEFT   , volumePlayback[i]); break;
+                   case Volume::REARSIDERIGHT: ret = snd_mixer_selem_set_playback_volume( elem, SND_MIXER_SCHN_SIDE_RIGHT  , volumePlayback[i]); break;
+                   default: kDebug() << "FATAL: Unknown channel type for playback << " << i << " ... please report this";  break;
+              }
+              if ( ret != 0 ) kDebug(67100) << "writeVolumeToHW(" << devnum << ") [set_playback_volume] failed, errno=" << ret;
+              if (id== "Master:0" || id== "PCM:0" ) { kDebug() << "volumePlayback control=" << id << ", chid=" << i << ", vol=" << volumePlayback[i]; }
+          }
+       }
+    } // has playback volume
 
     // --- playback switch
     if ( snd_mixer_selem_has_playback_switch( elem ) ||
@@ -754,14 +822,31 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, MixDevice *md )
         snd_mixer_selem_set_playback_switch_all(elem, sw);
     }
 
+
     // --- capture volume
-    left  = volumeCapture[ Volume::LEFT ];
-    right = volumeCapture[ Volume::RIGHT ];
-    if ( snd_mixer_selem_has_capture_volume( elem )) {
-        snd_mixer_selem_set_capture_volume ( elem, SND_MIXER_SCHN_FRONT_LEFT, left );
-        if ( ! snd_mixer_selem_is_playback_mono ( elem ) )
-            snd_mixer_selem_set_capture_volume ( elem, SND_MIXER_SCHN_FRONT_RIGHT, right );
-    }
+    if ( snd_mixer_selem_has_capture_volume ( elem ) )
+    {
+        for ( int i=0; i<= Volume::CHIDMAX; i++ ) {
+           if ( volumeCapture._chmask & Volume::_channelMaskEnum[i] ) {
+
+               int ret;
+               switch(i) {
+                   case Volume::LEFT         : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_FRONT_LEFT  , volumeCapture[i]); break;
+                   case Volume::RIGHT        : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_FRONT_RIGHT , volumeCapture[i]); break;
+                   case Volume::CENTER       : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_FRONT_CENTER, volumeCapture[i]); break;
+                   case Volume::SURROUNDLEFT : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_REAR_LEFT   , volumeCapture[i]); break;
+                   case Volume::SURROUNDRIGHT: ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_REAR_RIGHT  , volumeCapture[i]); break;
+                   case Volume::REARCENTER   : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_REAR_CENTER , volumeCapture[i]); break;
+                   case Volume::WOOFER       : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_WOOFER      , volumeCapture[i]); break;
+                   case Volume::REARSIDELEFT : ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_SIDE_LEFT   , volumeCapture[i]); break;
+                   case Volume::REARSIDERIGHT: ret = snd_mixer_selem_set_capture_volume( elem, SND_MIXER_SCHN_SIDE_RIGHT  , volumeCapture[i]); break;
+                   default: kDebug() << "FATAL: Unknown channel type for capture << " << i << " ... please report this";  break;
+              }
+              if ( ret != 0 ) kDebug(67100) << "writeVolumeToHW(" << devnum << ") [set_capture_volume] failed, errno=" << ret;
+              if (id== "Master:0" || id== "PCM:0" ) { kDebug() << "volumecapture control=" << id << ", chid=" << i << ", vol=" << volumeCapture[i]; }
+          }
+       }
+    } // has capture volume
 
     // --- capture switch
     if ( snd_mixer_selem_has_capture_switch( elem ) ) {
